import React, { useState } from 'react';
import { useNavigate } from "react-router-dom";
import { Menu } from 'antd';
import routes from '@/routes/routes';

// 菜单是否显示
// 没有 menu 或者 menu.title 为空, 或者 menu.hidden = true 的 都不显示
const isShow = item => item.menu && item.title && !item.menu.hidden;

const hasChildren = (list) => {
  if (!list || list.length < 1) return false;

  // 如果子元素全部都是不显示的, 说明子菜单不需要显示
  return list.filter(it => !isShow(it)).length !== list.length;
}

const getPath = (parent, current = '') => {
  if (current.indexOf('/') === 0 || current.indexOf('http') === 0) return current;
  return `${parent}/${current}`.replace(/\/\//g, '/');
}

const getItems = (dts = [], fullPath = '/') => {
  return dts.map(item => {
    // 没有 menu 或者 menu.title 为空, 或者 menu.hidden = true 的 都不显示
    if (!item.menu || !item.menu.title || item.menu.hidden) return false;
    
    const path = getPath(fullPath, item.path)
    const children = hasChildren(item.children) ? getItems(item.children, path) : false;

    return Object.assign(
      {
        key: path,
        label: item.menu.title,
        title: item.menu.title,
      },
      children && { children },
    )
  }).filter(Boolean);
}

const linkTo = url => {
  const a = document.createElement('a');
  a.href = item.key;
  a.target = '_blank';
  a.click();
}

export default (props) => {
  const { theme } = props;

  const navigate = useNavigate();
  const items = getItems(routes[0].children);

  const onClick = (item) => {
    // http 开头说明是外部链接
    if (item.key.indexOf('http') === 0) {
      linkTo(item.key);
    } else {
      navigate(item.key);
    }
  }

  return (
    <Menu theme={theme} items={items} onClick={onClick} />
  )
}
